.. _components:

Overview
=====================

This is the sumary of the available ``earthkit`` components.

.. list-table::
    :widths: 20 65 15
    :header-rows: 1

    * - Component
      - Description
      - Logo
    * - :xref:`earthkit-data`
      - Helps to get data into Python quickly and easily, without worrying about technical issues like data formats or input types - all while retaining interoperability with popular data science libraries like numpy, pandas and xarray.
      - .. image:: https://raw.githubusercontent.com/ecmwf/earthkit-data/main/docs/_static/earthkit-data.png
          :width: 120px
    * - :xref:`earthkit-maps`
      - Geospatial visualisation tools and templates
      - .. image:: https://raw.githubusercontent.com/ecmwf/earthkit-maps/develop/docs/_static/earthkit-maps.png
          :width: 120px
